@@ -1,5 +1,5 @@
 /*
-lregr.c Version 1.5.0 - Linear Regression Test
+lregr.c Version 1.7.0 - Linear Regression Test
 Copyright (C) 2005-2010  dondalah721@yahoo.com (Dondalah)
 
 This program is free software; you can redistribute it and/or
@@ -120,31 +120,14 @@ char **argv;
 	 "allocating Y array.\n");
       exit(1);
       } /* out of memory */
-   p = (double *) xlst;
-   q = (double *) p + size;
-   while (p < q) *p++ = rndfrac(sd);
 
    p = (double *) xlst;
    q = (double *) p + size;
-   while (p < q)
-      {
-      if (isnan(*p))
-         printf("xlst %f\n", *p);
-      p++;
-      } /* if xlst isnan */
-
-   p = (double *) ylst;
-   q = (double *) p + size;
    while (p < q) *p++ = rndfrac(sd);
 
    p = (double *) ylst;
    q = (double *) p + size;
-   while (p < q)
-      {
-      if (isnan(*p))
-         printf("ylst %f\n", *p);
-      p++;
-      } /* if ylst isnan */
+   while (p < q) *p++ = rndfrac(sd);
 
    sumx = sumxsqd = 0.0;
    p = (double *) xlst;
@@ -156,11 +139,6 @@ char **argv;
       p++;
       } /* for each value of x */
 
-   if (isnan(sumx))
-      printf("sumx %f\n", sumx);
-   if (isnan(sumxsqd))
-      printf("sumxsqd %f\n", sumxsqd);
-
    sumy = sumysqd = 0.0;
    p = (double *) ylst;
    q = (double *) p + size;
@@ -171,11 +149,6 @@ char **argv;
       p++;
       } /* for each value of y */
 
-   if (isnan(sumy))
-      printf("sumy %f\n", sumy);
-   if (isnan(sumysqd))
-      printf("sumysqd %f\n", sumysqd);
-
    sumxy = 0.0;
    p = (double *) xlst;
    q = (double *) p + size;
@@ -187,9 +160,6 @@ char **argv;
       r++;
       } /* for each corresponding x and y */
 
-   if (isnan(sumxy))
-      printf("sumxy %f\n", sumxy);
-
    /* least squares calculation */
    left   = sumxsqd * sumy;
    rght   = sumx * sumxy;
@@ -197,17 +167,7 @@ char **argv;
    left   = dblsz * sumxsqd;
    rght   = sumx  * sumx;
    bottom = left - rght;
-   if (isnan(left))
-      printf("left %f\n", left);
-   if (isnan(rght))
-      printf("rght %f\n", rght);
-   if (isnan(bottom))
-      printf("bottom %f\n", bottom);
    ycept  = top / bottom;
-   if (isnan(top))
-      printf("top %f\n", top);
-   if (isnan(ycept))
-      printf("ycept %f\n", ycept);
    printf("Y Intercept %10.6f\n", ycept);
    left   = dblsz * sumxy;
    rght   = sumx  * sumy;
